library(openxlsx)
library(ggplot2)

##図5.7
d0 <- read.xlsx('/*****/*****/*****/data_r1.xlsx', 
                sheet = 1)
#データを読み込む時は、上の「/*****/*****/*****/」を変更して下さい

head(d0,5)
ggplot(d0, aes(humid, temp_a))+
  geom_point()+
  xlab("平均湿度(%)")+
  ylab("平均気温(℃)")+
  theme_gray (base_family = "HiraKakuPro-W3")

#箱ヒゲ図
d1 <- read.xlsx('/*****/*****/*****/data_r1.xlsx', 
                 sheet = 2)
head(d1, 5)
ggplot(d1, aes(city_n, temp))+
  geom_boxplot()+
  xlab("")+
  ylab("最高気温(℃)")+
  theme_gray (base_family = "HiraKakuPro-W3")

#クロス集計表
#期間を6/1〜8/31に限定
d1$date<-as.Date(d1$date, origin = "1899-12-30")#dateの列を日付に変更
head(d1, 5) #指定ないと、6行目まで出力
d1_1<-subset(d1 , date >= as.Date("2021-06-01") & date <= as.Date("2021-08-31")  )
head(d1_1, 5)
d1_1$natsubi<-ifelse(d1_1$temp>=25,"夏日", "夏日でない") #25℃以上を夏日
t1<-table(d1_1$city_n, d1_1$natsubi)
addmargins(t1)#結果をエクセルで加工(addmargins():周辺和を追加)

##図5.8
#d1に「夏日」の列追加
library(dplyr)
d1$natsubi<-ifelse(d1$temp>=25,"夏日", "夏日でない")
head(d1,5) #確認

#グラフ描画
library(ggmosaic)
ggplot(d1_1) +
  geom_mosaic(aes(x = product(city_n, natsubi), fill=city_n) ) +
  labs(x = "夏日か否か", y = "都市") +
  theme_minimal() +
  theme_gray(base_family = "HiraKakuPro-W3")+
  theme(panel.grid = element_blank(), legend.title=element_blank())

##図5.9
d2 <- read.xlsx('/*****/*****/*****/data_r2.xlsx', 
                sheet = 1)
head(d2, 5)
d2<-mutate(d2, tozai=if_else(東西==1, "東", "西"))#mutate: 変数作成（dplyrの関数）
table(d2$東西, d2$tozai)#確認

#図5.9(左)
d2_1<-subset(d2,d2$カテゴリー=="しゅうまい")#d2_1:「しゅうまい」のみのデータ
table(d2_1$カテゴリー)#確認

ggplot(d2_1, aes(都市名, 金額, colour=tozai))+
  geom_point()+
  xlab("都道府県")+
  ylab("しゅうまいの金額（円/世帯）")+
  scale_colour_manual(values=c("grey70","grey30"))+
  theme_gray (base_family = "HiraKakuPro-W3")+
  theme(axis.text.x = element_blank(),
        legend.title=element_blank()) #x軸、凡例のタイトルを空欄に

##図5.9(右)
ggplot(d2, aes(カテゴリー, 金額, fill=tozai))+
  geom_boxplot()+
  xlab("")+
  ylab("世帯あたりの金額（円/世帯）")+
  scale_fill_manual(values=c("grey50","grey80"))+
  theme_gray (base_family = "HiraKakuPro-W3")+
  theme(legend.title=element_blank())

##図5.10
d3 <- read.xlsx('/*****/*****/*****/data_r1.xlsx', 
                sheet = 3)
head(d3,5)

ggplot(d3,aes(x = temp, fill = city_n))+
  geom_histogram(bins = 25, position = "nudge", color = "white", alpha = 1)+
  facet_grid(city_n ~ .)+
  theme_gray(base_family = "HiraKakuPro-W3")+
  theme(legend.position = "none")#凡例を非表示

##図5.13
ggplot(d2, aes(カテゴリー, 金額))+
  geom_violin()+
  xlab("")+
  ylab("世帯あたりの金額（円/世帯）")+
  theme_gray (base_family = "HiraKakuPro-W3")
  #中央値をプロットするには、以下のコードを追加
  stat_summary(fun = "median", geom = "point")

##図5.14
#散布図
library(readr)
d4<-read_csv('/*****/*****/*****/d_swb.csv')  
head(d4,5)
d4$Q1<-d4$Q1-1 #0-10に値を変換
d4$Q2<-d4$Q2-1 #0-10に値を変換
summary(d4)#確認

ggplot(d4, aes(Q2, Q1))+
  geom_point()+
  scale_x_continuous(breaks=c(0:10))+ #軸の範囲設定（下も同じ）
  scale_y_continuous(breaks=c(0:10))+
  xlab("満足度（家計と資産）")+
  ylab("満足度（全体）")+
  theme_gray (base_family = "HiraKakuPro-W3")

#図5.15
#データ作成
d4$dummy<-1
d4_1<-aggregate(dummy ~  Q1+Q2, d4, sum)
d4_1 #確認

#図5.15(左)
ggplot(d4_1, aes(as.factor(Q2), as.factor(Q1), fill=dummy))+
  geom_tile()+
  scale_fill_gradient(low="honeydew",high="royalblue4")+
  xlab("満足度（家計と資産）")+
  ylab("満足度（全体）")+
  theme_gray (base_family = "HiraKakuPro-W3")+
  theme(legend.title=element_blank())

#図5.15(右)
ggplot(d4_1, aes(Q2, Q1, size=dummy, alpha=dummy))+
  geom_point()+
  scale_x_continuous(breaks=c(0:10))+
  scale_y_continuous(breaks=c(0:10))+
  xlab("満足度（家計と資産）")+
  ylab("満足度（全体）")+
  theme_gray (base_family = "HiraKakuPro-W3")+
  theme(legend.title=element_blank())

##図5.17
ggplot(d2, aes(カテゴリー, 金額))+
  geom_boxplot(width=0.4)+   #width=数値で箱の幅を調整
  xlab("")+
  ylab("世帯あたりの金額（円/世帯）")+
  theme_gray (base_family = "HiraKakuPro-W3")

ggplot(d2, aes(カテゴリー, 金額))+
  geom_boxplot(width=0.4)+   #width=数値で箱の幅を調整
  geom_jitter(width = 0.15, alpha=0.5)+　#alpha=数値で点の透明度を調整
  xlab("")+
  ylab("世帯あたりの金額（円/世帯）")+
  theme_gray (base_family = "HiraKakuPro-W3")

##図5.18
#左
d5 <- read.xlsx('/*****/*****/*****/data_r2.xlsx', 
                sheet = 2)
ggplot(d5, aes(都市名, しゅうまい))+
  geom_point()+
  xlab("都道府県")+
  ylab("しゅうまいの金額（円/世帯）")+
  theme_gray (base_family = "HiraKakuPro-W3")+
  theme(axis.text.x = element_blank())            

#右上
ggplot(d5, aes(都市名, しゅうまい))+
  geom_point()+
  xlab("都道府県")+
  ylab("しゅうまいの金額（円/世帯）")+
  theme_gray (base_family = "HiraKakuPro-W3")+
  theme(axis.text.x = element_blank()) +
  geom_hline(yintercept=mean(d5[,2])) #平均値の線を描画

#右下
ggplot(d5, aes(都市名, しゅうまい))+
  geom_point()+
  xlab("都道府県")+
  ylab("しゅうまいの金額（円/世帯）")+
  theme_gray (base_family = "HiraKakuPro-W3")+
  theme(axis.text.x = element_blank()) +
  geom_hline(yintercept=mean(d5[,2])+sd(d5[,2]), linetype=2)+ #平均値+標準偏差の線を描画
  geom_hline(yintercept=mean(d5[,2])-sd(d5[,2]), linetype=2)　#  〃（下の破線）

##図5.19
#左
ggplot(d5, aes(しゅうまい, ぎょうざ))+
  geom_point()+
  xlab("しゅうまいの金額（円/世帯）")+
  ylab("ぎょうざの金額（円/世帯）")+
  theme_gray (base_family = "HiraKakuPro-W3")

#右
ggplot(d5, aes(しゅうまい, ぎょうざ))+
  geom_point()+
  xlab("しゅうまいの金額（円/世帯）")+
  ylab("ぎょうざの金額（円/世帯）")+
  geom_smooth(method="lm")+　　　　　#回帰直線の描画
  theme_gray (base_family = "HiraKakuPro-W3")

